==> RISmed_2.1.5.tar.gz: RISmed/R/AllGenerics.R <==
# RISmed GENERICS
setGeneric("QueryCount",function(object) standardGeneric("QueryCount"))
setGeneric("QueryId",function(object) standardGeneric("QueryId"))
setGeneric("QueryTranslation",function(object) standardGeneric("QueryTranslation"))
setGeneric("Query",function(object) standardGeneric("Query"))                                
setGeneric("PMID",function(object) standardGeneric("PMID"))                                
setGeneric("YearAccepted",function(object) standardGeneric("YearAccepted"))                                
setGeneric("MonthAccepted",function(object) standardGeneric("MonthAccepted"))                              
setGeneric("DayAccepted",function(object) standardGeneric("DayAccepted"))                                  
setGeneric("HourAccepted",function(object) standardGeneric("HourAccepted"))                                
setGeneric("MinuteAccepted",function(object) standardGeneric("MinuteAccepted"))                            
setGeneric("YearReceived",function(object) standardGeneric("YearReceived"))                                
setGeneric("MonthReceived",function(object) standardGeneric("MonthReceived"))                              
setGeneric("DayReceived",function(object) standardGeneric("DayReceived"))                                  
setGeneric("HourReceived",function(object) standardGeneric("HourReceived"))                                
setGeneric("MinuteReceived",function(object) standardGeneric("MinuteReceived"))                            
setGeneric("YearEpublish",function(object) standardGeneric("YearEpublish"))                                
setGeneric("MonthEpublish",function(object) standardGeneric("MonthEpublish"))                              
setGeneric("DayEpublish",function(object) standardGeneric("DayEpublish"))                                  
setGeneric("HourEpublish",function(object) standardGeneric("HourEpublish"))                                
setGeneric("MinuteEpublish",function(object) standardGeneric("MinuteEpublish"))                            
setGeneric("YearPpublish",function(object) standardGeneric("YearPpublish"))                                
setGeneric("MonthPpublish",function(object) standardGeneric("MonthPpublish"))                              
setGeneric("DayPpublish",function(object) standardGeneric("DayPpublish"))                                  
setGeneric("HourPpublish",function(object) standardGeneric("HourPpublish"))                                
setGeneric("MinutePpublish",function(object) standardGeneric("MinutePpublish"))                            
setGeneric("YearPmc",function(object) standardGeneric("YearPmc"))                                
setGeneric("MonthPmc",function(object) standardGeneric("MonthPmc"))                              
setGeneric("DayPmc",function(object) standardGeneric("DayPmc"))                                  
setGeneric("HourPmc",function(object) standardGeneric("HourPmc"))                                
setGeneric("MinutePmc",function(object) standardGeneric("MinutePmc"))     
setGeneric("YearPubmed",function(object) standardGeneric("YearPubmed"))                                
setGeneric("MonthPubmed",function(object) standardGeneric("MonthPubmed"))                              
setGeneric("DayPubmed",function(object) standardGeneric("DayPubmed"))                                  
setGeneric("HourPubmed",function(object) standardGeneric("HourPubmed"))                                
setGeneric("MinutePubmed",function(object) standardGeneric("MinutePubmed"))                         
setGeneric("Author",function(object) standardGeneric("Author"))                            
setGeneric("ISSN",function(object) standardGeneric("ISSN"))                                
setGeneric("Title",function(object) standardGeneric("Title"))                              
setGeneric("ArticleTitle",function(object) standardGeneric("ArticleTitle"))                
setGeneric("ELocationID",function(object) standardGeneric("ELocationID"))                  
setGeneric("AbstractText",function(object) standardGeneric("AbstractText"))                
setGeneric("Affiliation",function(object) standardGeneric("Affiliation"))                  
setGeneric("Language",function(object) standardGeneric("Language"))                        
setGeneric("PublicationType",function(object) standardGeneric("PublicationType"))          
setGeneric("MedlineTA",function(object) standardGeneric("MedlineTA"))                      
setGeneric("NlmUniqueID",function(object) standardGeneric("NlmUniqueID"))                  
setGeneric("ISSNLinking",function(object) standardGeneric("ISSNLinking"))                  
setGeneric("PublicationStatus",function(object) standardGeneric("PublicationStatus"))      
setGeneric("ArticleId",function(object) standardGeneric("ArticleId"))                      
setGeneric("Volume",function(object) standardGeneric("Volume"))                            
setGeneric("Issue",function(object) standardGeneric("Issue"))                              
setGeneric("ISOAbbreviation",function(object) standardGeneric("ISOAbbreviation"))          
setGeneric("MedlinePgn",function(object) standardGeneric("MedlinePgn"))                    
setGeneric("CopyrightInformation",function(object) standardGeneric("CopyrightInformation"))
setGeneric("Country",function(object) standardGeneric("Country"))                          
setGeneric("GrantID",function(object) standardGeneric("GrantID"))                          
setGeneric("Acronym",function(object) standardGeneric("Acronym"))                          
setGeneric("Agency",function(object) standardGeneric("Agency"))                            
setGeneric("RegistryNumber",function(object) standardGeneric("RegistryNumber"))            
setGeneric("RefSource",function(object) standardGeneric("RefSource"))                      
setGeneric("CollectiveName",function(object) standardGeneric("CollectiveName"))
setGeneric("Mesh",function(object) standardGeneric("Mesh"))
setGeneric("Cited", function(object) standardGeneric("Cited"))

==> RISmed_2.2.tar.gz: RISmed/R/AllGenerics.R <==
# RISmed GENERICS
setGeneric("QueryCount",function(object) standardGeneric("QueryCount"))
setGeneric("QueryId",function(object) standardGeneric("QueryId"))
setGeneric("QueryTranslation",function(object) standardGeneric("QueryTranslation"))
setGeneric("Query",function(object) standardGeneric("Query"))                                
setGeneric("PMID",function(object) standardGeneric("PMID"))   
setGeneric("YearRevised",function(object) standardGeneric("YearRevised"))                                
setGeneric("MonthRevised",function(object) standardGeneric("MonthRevised"))                              
setGeneric("DayRevised",function(object) standardGeneric("DayRevised"))                                  
setGeneric("YearPubDate",function(object) standardGeneric("YearPubDate"))                                
setGeneric("MonthPubDate",function(object) standardGeneric("MonthPubDate"))                              
setGeneric("DayPubDate",function(object) standardGeneric("DayPubDate"))                                  
setGeneric("YearArticleDate",function(object) standardGeneric("YearArticleDate"))                                
setGeneric("MonthArticleDate",function(object) standardGeneric("MonthArticleDate"))                              
setGeneric("DayArticleDate",function(object) standardGeneric("DayArticleDate"))                                  
setGeneric("YearEntrez",function(object) standardGeneric("YearEntrez"))                                
setGeneric("MonthEntrez",function(object) standardGeneric("MonthEntrez"))                              
setGeneric("DayEntrez",function(object) standardGeneric("DayEntrez"))                                  
setGeneric("HourEntrez",function(object) standardGeneric("HourEntrez"))                                
setGeneric("MinuteEntrez",function(object) standardGeneric("MinuteEntrez"))                            
setGeneric("YearMedline",function(object) standardGeneric("YearMedline"))                                
setGeneric("MonthMedline",function(object) standardGeneric("MonthMedline"))                              
setGeneric("DayMedline",function(object) standardGeneric("DayMedline"))                                  
setGeneric("HourMedline",function(object) standardGeneric("HourMedline"))                                
setGeneric("MinuteMedline",function(object) standardGeneric("MinuteMedline"))                            
                                   
setGeneric("YearAccepted",function(object) standardGeneric("YearAccepted"))                                
setGeneric("MonthAccepted",function(object) standardGeneric("MonthAccepted"))                              
setGeneric("DayAccepted",function(object) standardGeneric("DayAccepted"))                                  
setGeneric("HourAccepted",function(object) standardGeneric("HourAccepted"))                                
setGeneric("MinuteAccepted",function(object) standardGeneric("MinuteAccepted"))                            
setGeneric("YearReceived",function(object) standardGeneric("YearReceived"))                                
setGeneric("MonthReceived",function(object) standardGeneric("MonthReceived"))                              
setGeneric("DayReceived",function(object) standardGeneric("DayReceived"))                                  
setGeneric("HourReceived",function(object) standardGeneric("HourReceived"))                                
setGeneric("MinuteReceived",function(object) standardGeneric("MinuteReceived"))                            
setGeneric("YearEpublish",function(object) standardGeneric("YearEpublish"))                                
setGeneric("MonthEpublish",function(object) standardGeneric("MonthEpublish"))                              
setGeneric("DayEpublish",function(object) standardGeneric("DayEpublish"))                                  
setGeneric("HourEpublish",function(object) standardGeneric("HourEpublish"))                                
setGeneric("MinuteEpublish",function(object) standardGeneric("MinuteEpublish"))                            
setGeneric("YearPpublish",function(object) standardGeneric("YearPpublish"))                                
setGeneric("MonthPpublish",function(object) standardGeneric("MonthPpublish"))                              
setGeneric("DayPpublish",function(object) standardGeneric("DayPpublish"))                                  
setGeneric("HourPpublish",function(object) standardGeneric("HourPpublish"))                                
setGeneric("MinutePpublish",function(object) standardGeneric("MinutePpublish"))                            
setGeneric("YearPmc",function(object) standardGeneric("YearPmc"))                                
setGeneric("MonthPmc",function(object) standardGeneric("MonthPmc"))                              
setGeneric("DayPmc",function(object) standardGeneric("DayPmc"))                                  
setGeneric("HourPmc",function(object) standardGeneric("HourPmc"))                                
setGeneric("MinutePmc",function(object) standardGeneric("MinutePmc"))     
setGeneric("YearPubmed",function(object) standardGeneric("YearPubmed"))                                
setGeneric("MonthPubmed",function(object) standardGeneric("MonthPubmed"))                              
setGeneric("DayPubmed",function(object) standardGeneric("DayPubmed"))                                  
setGeneric("HourPubmed",function(object) standardGeneric("HourPubmed"))                                
setGeneric("MinutePubmed",function(object) standardGeneric("MinutePubmed"))                         
setGeneric("Author",function(object) standardGeneric("Author"))                            
setGeneric("ISSN",function(object) standardGeneric("ISSN"))                                
setGeneric("Title",function(object) standardGeneric("Title"))                              
setGeneric("ArticleTitle",function(object) standardGeneric("ArticleTitle"))                
setGeneric("ELocationID",function(object) standardGeneric("ELocationID"))                  
setGeneric("AbstractText",function(object) standardGeneric("AbstractText"))                
setGeneric("Affiliation",function(object) standardGeneric("Affiliation"))                  
setGeneric("Language",function(object) standardGeneric("Language"))                        
setGeneric("PublicationType",function(object) standardGeneric("PublicationType"))          
setGeneric("MedlineTA",function(object) standardGeneric("MedlineTA"))                      
setGeneric("NlmUniqueID",function(object) standardGeneric("NlmUniqueID"))                  
setGeneric("ISSNLinking",function(object) standardGeneric("ISSNLinking"))                  
setGeneric("PublicationStatus",function(object) standardGeneric("PublicationStatus"))      
setGeneric("ArticleId",function(object) standardGeneric("ArticleId"))      
setGeneric("DOI",function(object) standardGeneric("DOI"))                 
setGeneric("Volume",function(object) standardGeneric("Volume"))                            
setGeneric("Issue",function(object) standardGeneric("Issue"))                              
setGeneric("ISOAbbreviation",function(object) standardGeneric("ISOAbbreviation"))          
setGeneric("MedlinePgn",function(object) standardGeneric("MedlinePgn"))                    
setGeneric("CopyrightInformation",function(object) standardGeneric("CopyrightInformation"))
setGeneric("Country",function(object) standardGeneric("Country"))                          
setGeneric("GrantID",function(object) standardGeneric("GrantID"))                          
setGeneric("Acronym",function(object) standardGeneric("Acronym"))                          
setGeneric("Agency",function(object) standardGeneric("Agency"))                            
setGeneric("RegistryNumber",function(object) standardGeneric("RegistryNumber"))            
setGeneric("RefSource",function(object) standardGeneric("RefSource"))                      
setGeneric("CollectiveName",function(object) standardGeneric("CollectiveName"))
setGeneric("COIStatement",function(object) standardGeneric("COIStatement"))
setGeneric("Mesh",function(object) standardGeneric("Mesh"))
setGeneric("Cited", function(object) standardGeneric("Cited"))
